@@ -29,7 +29,7 @@ logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
 class BaseExperiment:
-    r"""Parent class of ``Experiment``.
+    """Parent class of ``Experiment``.
 
     BaseExperiment basically trains the model with a certain random state governing all random operations. When test data is not specified, the test data would also be splitted 
     differently depending on the randon state. To set a random state, you should specify the ``random_number`` argument as an input. This will set a random number generator with 
@@ -128,7 +128,7 @@ class BaseExperiment:
         random_number : int = 0,
         path : Optional[str] = "."
     )->None:
-        r"""
+        """
 
         Args:
 
@@ -176,6 +176,10 @@ class BaseExperiment:
 
             None
 
+        Example::
+
+            >>> exp = Experiment(project_name="MNIST", X=X, y=y, n_classes=10)
+
         """
         self.project_name = project_name
         self.X = X
@@ -230,15 +234,21 @@ class BaseExperiment:
         
 
     def update_log_path(self)->None:
-        r"""Updates log path
+        """Updates log path.
 
         """
         self.exp_path = f'{self.project_path}/{self.fit_or_cv}/random_state-{self.random_state}'
         self.log_path = f'{self.exp_path}/logs'
 
     def update_exp_metadata(self)->None:
-        r"""Upates exp_metadata.
-        
+        """Updates metadata for the experiment.
+
+        Experiment metadata contains the following::
+            - number of checkpoints(models) saved
+            - file size of the ``Experiment``(in MB).
+            - random state governing the experiment. 
+            - size of the data(in MB)
+
         """
         self.exp_metadata.update({'# of checkpoints saved' : int(self.n_ckpts)})
         self.exp_metadata.update({'size of the experiment in MB' : float(os.path.getsize(self.exp_path)/10**6)})
@@ -255,7 +265,7 @@ class BaseExperiment:
         model_type,
         **hparams : Any
     )->Union["pl.LightningModule", "BaseEstimator"]:
-        r"""Method for setting a model.
+        """Method for setting a model in the ``Experiment``.
 
         When calling set_model(), you should specify the class of the model (model_type)e.g., MLP, LitModel as an input argument together with their 
         configurations(**hparams).
@@ -331,7 +341,11 @@ class BaseExperiment:
     def get_data_module(
         self
     )->Union["pl.LightningDataModule", Tuple["np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray"]]:
-        r"""Method for getting a datamodule.
+        """Method for getting a datamodule.
+
+        ``self.data_module`` would be `LightningDataModule` if ``self.model`` is a `LightningModule` object. Tuple of 
+        (X_train, y_train, X_val, y_val, X_test, y_test) would be ``self.data_module`` if ``self.model`` is a `BaseEstimator` 
+        object.
 
         Returns:
 
@@ -465,7 +479,7 @@ class BaseExperiment:
     
     
     def set_trainer(self, **trainer_config)->"pl.Trainer":
-        r"""Method for getting trainer for the lightning model.
+        """Method for getting trainer for the lightning model.
 
         Args:
             
@@ -512,7 +526,11 @@ class BaseExperiment:
         fit_or_cv : str = "FIT",
         **config        
     )->Union["pl.LightningModule", "BaseEstimator"]:
-        r"""Method for training the model.
+        """Method for training the model.
+
+        ``self.model`` will be trained on `.fit()`. If ``self.model`` is a `LightningModule`, real-time tracking with 
+        TensorBoard is supported. If ``self.model`` is a `BaseEstimator`, only the result of the training would be
+        available.
 
         Args:
 
@@ -528,6 +546,10 @@ class BaseExperiment:
 
             `pl.LightningModule` or `BaseEstimator`: self.model
 
+        Example::
+
+            >>> exp.fit(**trainer_config)
+
         """
         
         if self.model is None:
@@ -644,7 +666,7 @@ class BaseExperiment:
         trainer : Optional["pl.Trainer"] = None,
         val_metrics : Optional[dict] = None
     )->None:
-        r"""Method for saving checkpoints. The logs are saved as json file as well.
+        """Method for saving checkpoints. The logs are saved as json file as well.
         
         Args:
 
@@ -737,7 +759,7 @@ class BaseExperiment:
         self.update_exp_metadata()
     
     def save_to_stack(self)->None:
-        r"""Method for stacking a model to ``stack``. If one of the ancestors of the model is ``BaseEstimator``, we only stack the model and its validation performance.
+        """Method for stacking a model to ``stack``. If one of the ancestors of the model is ``BaseEstimator``, we only stack the model and its validation performance.
         If one of the ancestors of the model is ``LightningModule``, we stack a dictionary containing the model, its trainer, and its validation performance.
 
         Returns:
@@ -807,7 +829,7 @@ class BaseExperiment:
    
     
     def save_stack(self)->None:
-        r"""Method for saving all model checkpoints in ``stack``.
+        """Method for saving all model checkpoints in ``stack``.
         
         Returns:
             
@@ -817,39 +839,34 @@ class BaseExperiment:
         
             ``stack`` will be flushed after saving.
 
+        Example::
+
+            >>> exp.stack
+            [{'model': MLP(
+                    (model): _MLP(
+                    (layers): Sequential(
+                        (0): Linear(in_features=64, out_features=10, bias=True)
+                        (1): ReLU()
+                        (2): Dropout(p=0, inplace=False)
+                        (3): Linear(in_features=10, out_features=10, bias=True)
+                        (4): Softmax(dim=1)
+                    )
+                    )
+                ),
+                'trainer': <pytorch_lightning.trainer.trainer.Trainer at 0x7f719df2cf10>,
+                'val_metrics': {'val/acc': 0.2898876368999481,
+                'val/loss': 2.158809185028076,
+                'val/auc': 0.7340054512023926}}]
+            
+            >>> exp.save_stack()
+            >>> exp.stack
+            []
+
         """
         for subject in self.stack:
             self.save_ckpt(**subject)
         del self.stack 
         self.stack = []
-    """
-    def delete_saved_model(
-        self,
-        model_type : Union["pl.LightningModule", "nn.Module", "BaseEstimator"],
-        version : int = -1, 
-        **hparams
-    ):
-        if not isinstance(version, int) or version <-1:
-            raise ValueError(f"Wrong value for version. Expected to be an integer greater than or equal to -1. Got {version} instead.")
-        if BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type) or SegNet in inspect.getmro(model_type):
-            pseudomodel = model_type(dims=self.dims, n_classes=self.n_classes, **hparams)
-        else:
-            pseudomodel = model_type(**hparams)
-        self.update_log_path()
-        model_metadata = self.set_model_metadata(pseudomodel, hparams)
-        ckpt_dir = f'{self.log_path}/checkpoints/{model_type.__name__}/{model_metadata}' 
-        jsonlog_dir = f'{self.log_path}/jsonlogs/{model_type.__name__}/{model_metadata}' 
-        tensorboard_dir =  f'{self.log_path}/tensorboardlogs/{model_type.__name__}/{model_metadata}' 
-        if version > -1:
-            ckpt_dir = f"{ckpt_dir}/version_{version}"
-            jsonlog_dir = f"{jsonlog_dir}/version_{version}"
-            tensorboard_dir = f"{tensorboard_dir}/version_{version}"
-        
-        shutil.rmtree(path=ckpt_dir)
-        shutil.rmtree(path=jsonlog_dir)
-        shutil.rmtree(path=tensorboard_dir)
-    """    
-
             
     def best_ckpt_thus_far(
         self, 
@@ -857,7 +874,7 @@ class BaseExperiment:
         mode : Optional[str] = None, 
         fetch_only_dir : bool = False
     ):
-        r"""Method for returning the best saved checkpoint(or the path name of the best saved checkpoint) from the directory. The criterion is the type of the validation metric.
+        """Method for returning the best saved checkpoint(or the path name of the best saved checkpoint) from the directory. The criterion is the type of the validation metric.
 
         Args:
 
@@ -872,6 +889,22 @@ class BaseExperiment:
             
             :obj:LightningModule or None: The best checkpoint(or the path if fetch_only_dir is True) as per the validation metric you defined in the argument. Returns None if there are no saved checkpoints
 
+        Example::
+
+            >>> exp.best_ckpt_thus_far(val_metric="val/auc")
+            (MLP(
+                (model): _MLP(
+                    (layers): Sequential(
+                    (0): Linear(in_features=64, out_features=10, bias=True)
+                    (1): ReLU()
+                    (2): Dropout(p=0, inplace=False)
+                    (3): Linear(in_features=10, out_features=10, bias=True)
+                    (4): Softmax(dim=1)
+                    )
+                )
+                ),
+                {'val/auc': 0.7340054512023926})
+
         """
         jsonlogdir = f"{self.log_path}/jsonlogs"
         if not mode:
@@ -948,7 +981,7 @@ class BaseExperiment:
         self, 
         val_metric : str = "val/acc"
     ):
-        r"""Method for returning the best saved checkpoint from the stack as per the validation metric.
+        """Method for returning the best saved checkpoint from the stack as per the validation metric.
 
         Args:
             
@@ -991,7 +1024,7 @@ class BaseExperiment:
         model: Union["pl.LightningModule", "BaseEstimator"],
         hparams : dict,
     )->str: 
-        r"""Method for generating metadata of the experiment.
+        """Method for generating metadata of the experiment.
         
         Args:
 
@@ -1021,7 +1054,7 @@ class BaseExperiment:
         return model_metadata
    
     def get_hparams(self, model):
-        r"""Gets hyperparameter or model specs.
+        """Gets hyperparameter or model specs.
 
         """
         if isinstance(model, BaseEstimator):
@@ -1038,7 +1071,7 @@ class BaseExperiment:
         jsonlog_path : str,
         metrics_dict : Optional[dict] = None
     )->None:
-        r"""Save results as a json file.
+        """Save results as a json file.
 
         Args:
 
@@ -1127,7 +1160,7 @@ class BaseExperiment:
 
 
     def toggle_stack(self):
-        r"""Toggles stack_models.
+        """Toggles stack_models.
 
         """
         self.stackflag = not self.stackflag
