@@ -18,7 +18,10 @@ applicable_optimizer_type_list = APPLICABLE_OPTIMIZER_TYPE_LIST
 
     
 class BaseNet(pl.LightningModule):
-    r"""BaseNet. Use this for models that don't deal with image data. 
+    """BaseNet. Use this for models that don't deal with image data. 
+
+    Descendants of BaseNet are typically a multi-layered perceptron and takes flattened
+    data as an input. 
 
         Attributes:
             
@@ -35,7 +38,7 @@ class BaseNet(pl.LightningModule):
         Note:
 
             BaseNet is the parent class for MLPs(MLP, ContractingMLP, CustomMLP). It is also
-            compatible with other MLPs that are written in pytorch_lightning.
+            compatible with other MLPs that are written in pytorch-lightning.
 
             When inheriting BaseNet, you only need to specify the structure of your MLP because 
             other magics are defined in BaseNet.  
@@ -43,6 +46,7 @@ class BaseNet(pl.LightningModule):
             BaseNet can perform both classification and regression tasks. If you specify n_classes, 
             BaseNet will recognize the task as a classification problem. If n_classes is not passed
             as a parameter for BaseNet, it will understand that the task is a regression problem.
+
     """
 
     def __init__(
@@ -54,8 +58,9 @@ class BaseNet(pl.LightningModule):
         scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **config : Any
     ) -> None:
-        r"""
-         Args: 
+        """
+
+        Args: 
             
             dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1)
 
@@ -66,6 +71,11 @@ class BaseNet(pl.LightningModule):
                 Default: {'scheduler' : None, 'scheduler_config' : None}
 
             **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+        
+        Returns:
+            
+            None
+
         """
         super(BaseNet, self).__init__()
         if not isinstance(dims, int):
@@ -118,11 +128,12 @@ class BaseNet(pl.LightningModule):
 
     @property
     def criterion(self):
-        r"""Criterion for loss function.
+        """Criterion for loss function.
 
         Returns:
 
             See astrape.utilities.utils for details.
+
         """
         if self.n_classes is None:
             if 'regression_metric' in self.config.keys():
@@ -275,19 +286,13 @@ class BaseNet(pl.LightningModule):
 
 
 class ConvNet(pl.LightningModule):
-    r"""ConvNet. Use this when using CNNs. 
+    """ConvNet. Use this when using CNNs. 
 
     Note:
 
-        ConvNet is the parent class for CNNs(VGG, UNet). It is also compatible with other CNNs
-        that are written in pytorch_lightning. 
+        ConvNet is the parent class for CNNs. It is also compatible with other CNNs
+        that are written in pytorch-lightning. 
 
-        When inheriting ConvNet, you only need to specify the structure of your MLP because 
-        other magics are defined in ConvNet. 
-
-        Currently in expytorch_lightning v. 0.0.0, ConvNet only supports basic classification
-        tasks such as classification using CE loss or dice loss. Other operations will be 
-        updated soon(Be tuned!).
 
     Attributes:
 
@@ -297,7 +302,8 @@ class ConvNet(pl.LightningModule):
 
         sample_weight (torch.Tensor or np.ndarray): Sample weights.
 
-        config (dict) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+        **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+
 """
     def __init__(
         self,
@@ -307,7 +313,8 @@ class ConvNet(pl.LightningModule):
         scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **config : Any
     )->None:
-        r"""
+        """
+
         Args: 
 
             n_classes (int, optional): Number of classes in the classification task. Leave it as None in regression tasks.
@@ -317,6 +324,7 @@ class ConvNet(pl.LightningModule):
                 Default: ``None``
 
             **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+
         """
         super(ConvNet, self).__init__()
         
@@ -362,11 +370,12 @@ class ConvNet(pl.LightningModule):
 
     @property
     def criterion(self):   
-        r"""Criterion for loss function.
+        """Criterion for loss function.
 
         Returns:
 
-            See astrape.utilities.utils for details.
+            Criterion. See astrape.utilities.utils for details.
+
         """
         if self.n_classes is None:
             if 'regression_metric' in self.config.keys():
@@ -520,7 +529,7 @@ class ConvNet(pl.LightningModule):
 
 
 class SegNet(pl.LightningModule):
-    r"""SegNet. Use this when using CNNs to perform Image Segmentation. 
+    """SegNet. Use this when using CNNs to perform Image Segmentation. 
 
     Note:
 
@@ -535,8 +544,9 @@ class SegNet(pl.LightningModule):
 
         sample_weight (torch.Tensor or np.ndarray): Sample weights.
 
-        config (dict) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
-"""
+        **config (Any): Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+
+    """
     def __init__(
         self,
         n_classes : Optional[int] = None,
@@ -545,7 +555,8 @@ class SegNet(pl.LightningModule):
         scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **config : Any
     )->None:
-        r"""
+        """
+
         Args: 
 
             n_classes (int, optional): Number of classes in the classification task. Leave it as None in regression tasks.
@@ -555,6 +566,7 @@ class SegNet(pl.LightningModule):
                 Default: ``None``
 
             **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+
         """
         super(SegNet, self).__init__()
         
@@ -568,11 +580,12 @@ class SegNet(pl.LightningModule):
 
     @property
     def criterion(self):   
-        r"""Criterion for loss function.
+        """Criterion for loss function.
 
         Returns:
 
-            See astrape.utilities.utils for details.
+            Criterion. See astrape.utilities.utils for details.
+
         """
         if self.n_classes is None:
             raise AssertionError(f"Please pass the # of classes.")
@@ -744,48 +757,3 @@ class SegNet(pl.LightningModule):
             "interval" : "step"
         }
         return {"optimizer": optimizer, "lr_scheduler":scheduler_dict}
-"""
-class GenerativeNet(pl.LightningModule):
-    def __init__(
-        self,
-        dims : Union[int, Tuple[int]],
-        sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None,
-        **config : Any
-    )->None:
-        super(GenerativeNet, self).__init__()
-
-        self.dims = dims
-        self.config = config
-        self.sample_weight = sample_weight
-        self.save_hyperparameters(*config)
-
-
-    def on_after_batch_transfer(self, batch, dataloader_idx=0):
-        # modify this part if you want to perform model reweigthing.
-        self.sample_weight = torch.ones_like(batch[1]).type_as(batch[1])
-        return batch
-        
-    def reset_weights(self, module):
-        if isinstance(module, nn.Linear):
-            module.reset_parameters()
-            
-    def _init_weights(self, module):
-        if isinstance(module, nn.Linear):
-            nn.init.kaiming_normal_(module.weight)
-        elif isinstance(module, nn.BatchNorm1d):
-            nn.init.constant_(module.weight, 1)
-            nn.init.constant_(module.bias, 0)
-
-    def configure_optimizers(self):
-
-        #optimizer_type_check(applicable_optimizer_type_list, self.config.optimizer_type)
-        if self.hparams.optimizer_type == "adam":
-            optimizer = torch.optim.Adam(self.parameters(),
-                                     lr=self.hparams.lr
-                                     )
-        elif self.hparams.optimizer_type == "sgd":
-            optimizer = torch.optim.SGD(self.parameters(),
-                                        lr=self.hparams.lr)
-        
-        return optimizer
-"""
\ No newline at end of file
