@@ -16,7 +16,7 @@ from astrape.constants import *
 from torchvision import models
 
 class _MLP(nn.Module):
-    r"""Multilayer perceptron with identical # of hidden units.
+    """Multilayer perceptron with identical # of hidden units.
 
     Args:
 
@@ -162,7 +162,7 @@ class _MLP(nn.Module):
 
 
 class MLP(BaseNet):
-    r"""Multi-layer perceptron with identical # of hidden units.
+    """Multi-layer perceptron with identical # of hidden units.
 
     """
     def __init__(
@@ -173,37 +173,37 @@ class MLP(BaseNet):
         scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams
     ) -> None:
-        r"""Multi-layer perceptron with identical # of hidden units.
+        """Multi-layer perceptron with identical # of hidden units.
 
-            Args:
+        Args:
 
-                dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+            dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
 
-                n_classes (int, optional): Number of classes (labels) in the classification task.
-                
-                n_layers (int): Number of layers. If 1, it would be an old-school perceptron i.e., logistic regression.
-                    Default: ``2``
+            n_classes (int, optional): Number of classes (labels) in the classification task.
+            
+            n_layers (int): Number of layers. If 1, it would be an old-school perceptron i.e., logistic regression.
+                Default: ``2``
 
-                n_hidden_units (int): Number of hidden units for all hidden layers. 
-                    Default : ``10`` 
+            n_hidden_units (int): Number of hidden units for all hidden layers. 
+                Default : ``10`` 
 
-                batch_size (int): Batch size. 
-                    Default : ``64``
+            batch_size (int): Batch size. 
+                Default : ``64``
 
-                optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
-                    Default : ``"adam"`` 
+            optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+                Default : ``"adam"`` 
 
-                dropout_p (float): Dropout probability 
-                    Default : ``0``
+            dropout_p (float): Dropout probability 
+                Default : ``0``
 
-                bn (bool): Whether to use batch normalization or not. 
-                    Default : ``True``
+            bn (bool): Whether to use batch normalization or not. 
+                Default : ``True``
 
-                weight_decay (float): Coefficient for L2-regularization. 
-                    Default : ``0`` 
+            weight_decay (float): Coefficient for L2-regularization. 
+                Default : ``0`` 
 
-                lr (float): Learning rate. 
-                    Default: ``1e-4``
+            lr (float): Learning rate. 
+                Default: ``1e-4``
 
         """
         
@@ -259,7 +259,7 @@ class MLP(BaseNet):
 
 
 class _ContractingMLP(nn.Module):
-    r"""ContractingMLP with given contraction ratio.
+    """ContractingMLP with given contraction ratio.
 
     _ContractingMLP and ContractingMLP defines an MLP with number of hidden units decreasing with a factor
     of contraction_ratio.
@@ -287,34 +287,34 @@ class _ContractingMLP(nn.Module):
         negative_slope : Optional[float] = None,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
     ) -> None:
-        r"""Initialize ContractingMLP
+        """Initialize ContractingMLP
         
-            Args:
+        Args:
+        
+            dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+
+            n_classes (int, optional): Number of classes (labels) in the classification task.
             
-                dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+            contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
+                Default: ``0.5``
 
-                n_classes (int, optional): Number of classes (labels) in the classification task.
-                
-                contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
-                    Default: ``0.5``
+            batch_size (int): Batch size. 
+                Default : ``64``
 
-                batch_size (int): Batch size. 
-                    Default : ``64``
+            optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+                Default : ``"adam"`` 
 
-                optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
-                    Default : ``"adam"`` 
+            dropout_p (float): Dropout probability 
+                Default : ``0``
 
-                dropout_p (float): Dropout probability 
-                    Default : ``0``
+            bn (bool): Whether to use batch normalization or not. 
+                Default : ``True``
 
-                bn (bool): Whether to use batch normalization or not. 
-                    Default : ``True``
+            weight_decay (float): Coefficient for L2-regularization. 
+                Default : ``0`` 
 
-                weight_decay (float): Coefficient for L2-regularization. 
-                    Default : ``0`` 
-
-                lr (float): Learning rate. 
-                    Default: ``1e-4``
+            lr (float): Learning rate. 
+                Default: ``1e-4``
                     
     """
         super(_ContractingMLP, self).__init__()
@@ -464,7 +464,7 @@ class _ContractingMLP(nn.Module):
         return self.layers(X)
 
 class ContractingMLP(BaseNet):
-    r"""ContractingMLP with given contraction ratio.
+    """ContractingMLP with given contraction ratio.
     
     _ContractingMLP and ContractingMLP defines an MLP with number of hidden units decreasing with a factor
     of contraction_ratio.
@@ -482,34 +482,34 @@ class ContractingMLP(BaseNet):
         scheduler_config: Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams : Any
     ) -> None:
-        r"""Initialize ContractingMLP
+        """Initialize ContractingMLP
         
-            Args:
+        Args:
+        
+            dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+
+            n_classes (int, optional): Number of classes (labels) in the classification task.
             
-                dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1), (32,32,3)
+            contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
+                Default: ``0.5``
 
-                n_classes (int, optional): Number of classes (labels) in the classification task.
-                
-                contraction_ratio (float): The 0<contraction ratio<1 of the model. Number of hidden units contracts with this ratio.
-                    Default: ``0.5``
+            batch_size (int): Batch size. 
+                Default : ``64``
 
-                batch_size (int): Batch size. 
-                    Default : ``64``
+            optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+                Default : ``"adam"`` 
 
-                optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
-                    Default : ``"adam"`` 
+            dropout_p (float): Dropout probability 
+                Default : ``0``
 
-                dropout_p (float): Dropout probability 
-                    Default : ``0``
+            bn (bool): Whether to use batch normalization or not. 
+                Default : ``True``
 
-                bn (bool): Whether to use batch normalization or not. 
-                    Default : ``True``
+            weight_decay (float): Coefficient for L2-regularization. 
+                Default : ``0`` 
 
-                weight_decay (float): Coefficient for L2-regularization. 
-                    Default : ``0`` 
-
-                lr (float): Learning rate. 
-                    Default: ``1e-4``
+            lr (float): Learning rate. 
+                Default: ``1e-4``
 
         """
         
@@ -565,7 +565,7 @@ class ContractingMLP(BaseNet):
 
 
 class _CustomMLP(nn.Module):
-    r"""
+    """
     _CustomMLP and CustomMLP defines an MLP with number of hidden units for hidden layers 
     customized for all layers. 
 
@@ -1066,15 +1066,7 @@ class ResNet18(ConvNet):
         return self.model(X)
 
 class _UNet(nn.Module):
-    r"""
-    Paper: `U-Net: Convolutional Networks for Biomedical Image Segmentation
-    <https://arxiv.org/abs/1505.04597>`
-    Args:
-        n_classes: Number of output classes required
-        dims : Dimension of the input
-        num_layers: Number of layers in each side of U-net (default 5)
-        features_start: Number of features in first layer (default 64)
-        bilinear: Whether to use bilinear interpolation or transposed convolutions (default) for upsampling.
+    """Paper: `U-Net: Convolutional Networks for Biomedical Image Segmentation <https://arxiv.org/abs/1505.04597>`
 
     """
 
