@@ -33,7 +33,7 @@ available_domain_types = ["points", "image", "audio"]
 
 
 class BaseProject:
-    r"""Parent class of ``Project`` class. 
+    """Parent class of ``Project`` class. 
     
     Methods will perform 1)plotting data, 2)generating ``Experiments``,
     3)setting models across the generated `Experiment`s, 4)setting trainers across the generated ``Experiments``,
@@ -78,6 +78,7 @@ class BaseProject:
         n_exps (int): Number of ``Experiemnt``s in ``exps``.
 
         pseudoexp (`Experiment`): Dummy ``Experiment`` for applying methods in ``Experiment``.
+
     """
 
     def __init__(
@@ -91,7 +92,7 @@ class BaseProject:
         stratify : bool = True,
         path : str = "."
     )->None:
-        r"""Creates a ``Project``.
+        """Creates a ``Project``.
 
         Args:
             
@@ -119,6 +120,7 @@ class BaseProject:
         Returns:
 
             None
+
         """
         self.project_name = project_name
         self.X = X
@@ -160,7 +162,8 @@ class BaseProject:
     def update_project_metadata(
         self
     )->None:
-        r"""Updates metadata of the project.
+        """Updates metadata of the project.
+
         """
         self.project_metadata.update({'number of Experiments created' : self.n_exp})
         self.project_metadata.update({'size of this Project in MB' : float(os.path.getsize(self.project_path)/10**6)})
@@ -172,8 +175,10 @@ class BaseProject:
     def delete_empty_exps(
         self
     )->None:
-        r"""Delete empty experiments (if any). 
+        """Delete empty experiments (if any). 
+
         This will delete empty {path}/{project_name}/FIT/random_state_{random_state} folder.
+
         """
         path = f"{self.path}/{self.project_name}/FIT"
         for exp in os.listdir(path):
@@ -211,6 +216,10 @@ class BaseProject:
         Returns:
             
             dict: dictionary of ``Experiments``. Will be ``exps`` if ``stack_exps`` is True, dictionary of ``Experiments`` if ``stack_exps`` is False.
+
+        Example::
+
+            >>> project.create_experiments(amount=10)
         
         """
         exp_common_parameters = {
@@ -256,7 +265,7 @@ class BaseProject:
         self,
         experiment : Experiment
     )->None:
-        r"""Add an individual ``Experiment`` to ``exps``.
+        """Add an individual ``Experiment`` to ``exps``.
 
         Args:
 
@@ -265,6 +274,7 @@ class BaseProject:
         Returns:
 
             None
+
         """
         random_state = experiment.random_state
         if random_state in self.random_states:
@@ -280,7 +290,7 @@ class BaseProject:
         random_states : Optional[List[int]] = None, # if None, same models are set for all experiments created in the Project
         **hparams
     )->None:
-        r"""Set identical models across ``Experiments``.
+        """Set identical models across ``Experiments``.
 
         Args:
 
@@ -294,6 +304,7 @@ class BaseProject:
         Returns:
 
             None
+
         """
         random_state_str_list = []
         
@@ -316,7 +327,7 @@ class BaseProject:
         random_states : Optional[List[int]] = None, # if None, same trainers are set for all experiments created in the Project
         **trainer_config
     )->None:
-        r"""Set identical trainers across ``Experiments``.
+        """Set identical trainers across ``Experiments``.
 
         Args:
 
@@ -350,7 +361,7 @@ class BaseProject:
         random_states : Optional[List[int]] = None, # if None, all experiments will be fitted,
         **trainer_config
     )->None:
-        r"""Fit models in ``Experiments`` stacked in ``exps``.
+        """Fit models in ``Experiments`` stacked in ``exps``.
 
         Args:
 
@@ -383,7 +394,7 @@ class BaseProject:
         self,
         random_states : Optional[List[int]] = None, # if None, all experiments will save checkpoints
     )->None:
-        r"""Save checkpoints in ``Experiments`` stacked in ``exps``.
+        """Save checkpoints in ``Experiments`` stacked in ``exps``.
 
         Args:
 
@@ -413,7 +424,7 @@ class BaseProject:
         self,
         random_states : Optional[List[int]] = None, # if None, all experiments will save stacks
     )->None:
-        r"""Apply ``save_stack()`` for ``Experiments`` in ``exps``.
+        """Apply ``save_stack()`` for ``Experiments`` in ``exps``.
 
         Args:
 
@@ -442,7 +453,8 @@ class BaseProject:
     def save_project(
         self
     )->None:
-        r"""Save all ``Experiments``.
+        """Save all ``Experiments``.
+
         """
         if self.exps:
             self.save_stacks()
@@ -466,7 +478,7 @@ class BaseProject:
         dataformats : Optional[str] = "NCHW",
         n_data : Optional[int] = 10
     )->None:
-        r"""Visualizes the data.
+        """Visualizes the data.
         
         Args:
 
@@ -481,6 +493,7 @@ class BaseProject:
         Returns:
 
             None
+
         """
         points_dir = self.project_path + "/visualizations"
         self._create_folder(points_dir)
@@ -697,11 +710,12 @@ class BaseProject:
     def get_available_random_states(
         self
     )->List[str]:
-        r"""Returns list of directories of ``Experiments`` that has been fitted and logged.
+        """Returns list of directories of ``Experiments`` that has been fitted and logged.
 
         Returns:
 
             list of `str`: All directories of fitted and logged ``Experiments``.
+
         """
         log_base_dir = f"{self.project_path}/FIT"
         random_state_dir_list = []
@@ -714,7 +728,7 @@ class BaseProject:
         self,
         val_metric : str = 'val/acc'
     )->Tuple["np.ndarray", Dict[str,int], Dict[str,int]]: 
-        r"""Search method for finding the model type/structure with best validation performance.
+        """Search method for finding the model type/structure with best validation performance.
 
         Args:
 
@@ -786,7 +800,7 @@ class BaseProject:
         model_type : Union["pl.LightningModule", "BaseEstimator"],
         val_metric : str = 'val/acc'
     )->Tuple["np.ndarray",Dict[str,int]]:
-        r"""Search method for finding validation performances for a specific model type.
+        """Search method for finding validation performances for a specific model type.
 
         Args:
 
@@ -798,6 +812,7 @@ class BaseProject:
         Returns:
 
             tuple: (numpy ndarray of validation performances, dictionary of {model structure:it's frequency}).
+
         """
         performances = []
         best_model_structures = {}
@@ -852,7 +867,7 @@ class BaseProject:
         val_metric : str = 'val/acc',
         **hparams
     )->Tuple["np.ndarray", str]:
-        r"""Search method for finding validation performances of a specific model structure.
+        """Search method for finding validation performances of a specific model structure.
 
         Args:
 
@@ -866,6 +881,7 @@ class BaseProject:
         Returns:
 
             tuple: (numpy ndarray of validation performances, metadata specifying the specified model structure).
+
         """
         performances = []
         best_val = None
@@ -914,7 +930,7 @@ class BaseProject:
         self,
         val_metric : str = 'val/acc'
     )->Tuple["np.ndarray", List[str]]:
-        r"""Method for searching validation performances of all saved models.
+        """Method for searching validation performances of all saved models.
 
         Args:
 
@@ -924,6 +940,7 @@ class BaseProject:
         Returns:
 
             tuple: (numpy ndarray of list of validation performances, list of searched model metadata)
+
         """
         metadata_list = []
         performances_list = [] # list of performances(list). len(performances_list) == len(metadata_list)
@@ -974,7 +991,7 @@ class BaseProject:
 
     @staticmethod
     def _create_folder(directory : str)->str: #path of directory
-        r"""Creates folder.
+        """Creates folder.
         
         Args:
 
@@ -983,6 +1000,7 @@ class BaseProject:
         Returns: 
 
             str: directory 
+
         """
         os.makedirs(directory, exist_ok=True)
         return directory
@@ -991,7 +1009,7 @@ class BaseProject:
         
 
 class Project(BaseProject):
-    r"""Project class that plots results of the ML project.
+    """Project class that plots results of the ML project.
 
     Attributes:
 
@@ -1031,9 +1049,6 @@ class Project(BaseProject):
 
         pseudoexp (`Experiment`): Dummy ``Experiment`` for applying methods in ``Experiment``.
 
-    Methods:
-
-
     """
     def __init__(
         self,
@@ -1046,7 +1061,7 @@ class Project(BaseProject):
         stratify : bool = True,
         path : str = "."
     )->None:
-        r"""
+        """
         
         Args:
 
@@ -1070,6 +1085,7 @@ class Project(BaseProject):
             
             path : Base path for the project. Default is the current directory.
                 Default: ``.``        
+
         """
         super().__init__(
             project_name=project_name,
@@ -1086,61 +1102,61 @@ class Project(BaseProject):
             self,
             val_metric : str = 'val/acc',
             plt_title : Optional[str] = None
-        )->Tuple["np.ndarray",Dict[str,Dict[str,int]]]: # (validation performances, information)
-            r"""Plots the best validation performance for each ``Experiment``.
+    )->Tuple["np.ndarray",Dict[str,Dict[str,int]]]: # (validation performances, information)
+        """Plots the best validation performance for each ``Experiment``.
 
-            Args:
+        Args:
 
-                val_metric (str): The validation metric.
-                    Default: ``'val/acc'``
+            val_metric (str): The validation metric.
+                Default: ``'val/acc'``
 
-                plt_title (str, optional): The title for the plot. If left None, title will be 'Best Performance for Each Random State'.
-                    Default: None
+            plt_title (str, optional): The title for the plot. If left None, title will be 'Best Performance for Each Random State'.
+                Default: None
 
-            Returns:
+        Returns:
 
-                tuple: (numpy ndarray of validation performances, dictionary containing information of the search)
-            
-            """
-            performances, best_model_types, best_model_structures = self.search_standard(val_metric)
-            random_state_dir_list = self.get_available_random_states()
-            ymin = performances.min() - 0.1 if performances.min() > 0.1 else 0
-            ymax = performances.max() + 0.1 if performances.max() < 0.9 else 1
-            random_number_list = []
-            for random_number_dir in random_state_dir_list:
-                random_number = random_number_dir.split("-")[-1]
-                random_number_list.append(random_number)
-            fig1 = plt.figure()
-            x = np.arange(len(performances)) / 2
-            plt.bar(x, performances, width=0.1)
-            plt.xticks(x, random_number_list)
-            plt.xticks(rotation=70)
-            plt.xlabel("random state")
-            plt.grid(True)
-            plt.ylabel(val_metric)
+            tuple: (numpy ndarray of validation performances, dictionary containing information of the search)
+        
+        """
+        performances, best_model_types, best_model_structures = self.search_standard(val_metric)
+        random_state_dir_list = self.get_available_random_states()
+        ymin = performances.min() - 0.1 if performances.min() > 0.1 else 0
+        ymax = performances.max() + 0.1 if performances.max() < 0.9 else 1
+        random_number_list = []
+        for random_number_dir in random_state_dir_list:
+            random_number = random_number_dir.split("-")[-1]
+            random_number_list.append(random_number)
+        fig1 = plt.figure()
+        x = np.arange(len(performances)) / 2
+        plt.bar(x, performances, width=0.1)
+        plt.xticks(x, random_number_list)
+        plt.xticks(rotation=70)
+        plt.xlabel("random state")
+        plt.grid(True)
+        plt.ylabel(val_metric)
 
-            if not plt_title:
-                plt_title = 'Best Performance for Each Random State'
-            plt.title(plt_title)
-            plt.ylim = (ymin, ymax)
-            self._create_folder(f"{self.project_path}/results")
-            plt.show()
-            file_name = plt_title.replace(" ", "-")
-            plt.savefig(self.project_path+f"/results/{file_name}.png")
-            self.project_logger.add_figure(f"results/{plt_title}", fig1)
-            
-            plt.close(fig1)
+        if not plt_title:
+            plt_title = 'Best Performance for Each Random State'
+        plt.title(plt_title)
+        plt.ylim = (ymin, ymax)
+        self._create_folder(f"{self.project_path}/results")
+        plt.show()
+        file_name = plt_title.replace(" ", "-")
+        plt.savefig(self.project_path+f"/results/{file_name}.png")
+        self.project_logger.add_figure(f"results/{plt_title}", fig1)
+        
+        plt.close(fig1)
 
-            info = {'best model structures' : best_model_structures, 'best model types' : best_model_types}
+        info = {'best model structures' : best_model_structures, 'best model types' : best_model_types}
 
-            return (performances, info)
+        return (performances, info)
 
     def plot_best_model_frequencies(
         self,
         val_metric : str = 'val/acc',
         plt_title : Optional[str] = None
     )->Tuple["np.ndarray",Dict[str,Dict[str,int]]]: # (validation performances, information)
-        r"""Plots pie graphs showing the frequencies of 1)best model type and 2)best model structure for each ``Experiment``.
+        """Plots pie graphs showing the frequencies of 1)best model type and 2)best model structure for each ``Experiment``.
 
         Args:
 
@@ -1195,7 +1211,7 @@ class Project(BaseProject):
         val_metric : str = "val/acc",
         plt_title : Optional[str] = None
     )->Tuple["np.ndarray", List[str], Dict[str,Dict[str,int]]]: 
-        r"""Plots validation performances across different random states for a given model type.
+        """Plots validation performances across different random states for a given model type.
 
         Args:
 
@@ -1252,7 +1268,7 @@ class Project(BaseProject):
         plt_title : Optional[str] = None,
         **hparams
     )->Tuple["np.ndarray",List[str]]: 
-        r"""Plots validation performances across different random states for a given model structure.
+        """Plots validation performances across different random states for a given model structure.
 
         Args:
 
@@ -1315,7 +1331,7 @@ class Project(BaseProject):
     
     @staticmethod
     def generate_marker_style(amount)->List[str]: 
-        r"""Returns a string specifying the marker style
+        """Returns a string specifying the marker style
         
         """
         color_list = ['b','g','r','c','m','y','k','w']
@@ -1334,7 +1350,7 @@ class Project(BaseProject):
         val_metric : str = "val/acc",
         plt_title : Optional[str] = None
     )->Tuple["np.ndarray", List[str]]:
-        r"""Plots validation performances across different random states for all model structures saved. 
+        """Plots validation performances across different random states for all model structures saved. 
         
         Will plot 1)line graphs and 2)box plots.
 
